@@ -1,6 +1,6 @@
 package Audio::Nama::EcasoundRun;
 use Role::Tiny;
-use Modern::Perl '2020';
+use Modern::Perl;
 use Audio::Nama::Globals qw(:all);
 use Audio::Nama::Log qw(logpkg logsub);
 sub start { 
@@ -78,7 +78,7 @@ sub start_command { $_[0]->ecasound_iam('start') }
 ### routines defined in the root namespace
 
 package Audio::Nama;
-use Modern::Perl '2020'; use Carp;
+use Modern::Perl; use Carp;
 no warnings 'uninitialized';
 use Audio::Nama::Util qw(process_is_running);
 
