@@ -8,7 +8,7 @@ use Audio::Nama::Globals qw(:singletons :trackrw);
 #  -  edit name (i.e. sax-v1) used as key in %by_name
 #
 
-use Modern::Perl '2020';
+use Modern::Perl;
 our $VERSION = 1.0;
 use Carp;
 no warnings qw(uninitialized);
@@ -246,7 +246,7 @@ sub edit_track 		{ $Audio::Nama::tn{$_[0]->edit_name} }             # in version
 # -------- Edit routines; Main Namespace ------
 {
 package Audio::Nama;
-use Modern::Perl '2020'; use Carp;
+use Modern::Perl; use Carp;
 no warnings 'uninitialized';
 
 our (
@@ -304,7 +304,7 @@ sub get_edit_mark {
 		reset_input_line();
 		if( $p == 3){ complete_edit_points() }
 		else{
-			$term->stuff_char(10);
+			$text->{term}->stuff_char(10);
 			&{$text->{term_attribs}->{'callback_read_char'}}();
 		}
 	}
@@ -470,13 +470,13 @@ sub end_edit_mode  	{
 }
 sub destroy_edit {
 	Audio::Nama::throw("no edit selected"), return unless $this_edit;
-	my $reply = $term->readline('destroy edit "'.$this_edit->edit_name.
+	my $reply = $text->{term}->readline('destroy edit "'.$this_edit->edit_name.
 		qq(" and all its WAV files?? [n] ));
 	if ( $reply =~ /y/i ){
 		Audio::Nama::pager("permanently removing edit");
 		$this_edit->destroy;
 	}
-	$term->remove_history($term->where_history);
+	$text->{term}->remove_history($text->{term}->where_history);
 	$this_track = $this_edit->host;
 	end_edit_mode();
 }
