@@ -7,7 +7,7 @@ use Carp;
 use warnings;
 no warnings qw(uninitialized);
 our @ISA;
-use vars qw($n %by_index);
+our($n, %by_index);
 use Audio::Nama::Globals qw(:singletons %tn @fade_data); 
 use Audio::Nama::Log qw(logsub logpkg);
 use Audio::Nama::Effect  qw(remove_effect add_effect update_effect);
@@ -24,14 +24,6 @@ use Audio::Nama::Object qw(
 				 );
 initialize();
 
-# example
-#
-# if fade time is 10 for a fade out
-# and fade start time is 0:
-#
-# from 0 to 9, fade from 0 (100%) to -64db
-# from 9 to 10, fade from -64db to -256db
-
 sub initialize { 
 	%by_index = (); 
 	@fade_data = (); # for save/restore
@@ -58,13 +50,11 @@ sub new {
 
 	logpkg(__FILE__,__LINE__,'debug',"object class: $class, object type: ", ref $object);
 
-	my $id = add_fader($object->track);	# only when necessary
+	my $id = add_fader($object->track);
 	
 	my $track = $tn{$object->track};
 
-	# add linear envelope controller -klg if needed
-	
-	refresh_fade_controller($track);
+	Audio::Nama::request_setup(); # fades take effect after next engine stop
 	$object
 	
 }
@@ -73,34 +63,28 @@ sub new {
 
 sub refresh_fade_controller {
 	my $track = shift;
+	my @pairs = fader_envelope_pairs($track);
+	add_fader($track->name);	
 	my $operator  = Audio::Nama::fxn($track->fader)->type;
 	my $off_level = $config->{mute_level}->{$operator};
 	my $on_level  = $config->{unity_level}->{$operator};
-	my $controller;
-	($controller) = @{Audio::Nama::fxn($track->fader)->owns} if $track->fader;
-	if( $controller )
+	my @controllers = @{Audio::Nama::fxn($track->fader)->owns};
+	logpkg(__FILE__,__LINE__,'debug',$track->name, ": existing controllers: @controllers");
+	for my $controller (@controllers)
 	{
-		logpkg(__FILE__,__LINE__,'debug',$track->name, ": existing controller: $controller");
-		logpkg(__FILE__,__LINE__,'debug',"removing fade controller");
+		logpkg(__FILE__,__LINE__,'debug',"removing fade controller $controller");
 		remove_effect($controller);
 	}
 
-	return unless
-		my @pairs = fader_envelope_pairs($track); 
-
-	# add fader if it is missing
-
-	add_fader($track->name);	
-
 	# add controller
+	my $reuseid = pop @controllers; # we expect only one
 	logpkg(__FILE__,__LINE__,'debug',"applying fade controller");
-
-	# we try to re-use the controller ID
 	add_effect({
-		id			=> $controller,
+		track		=> $track,
+		id			=> $reuseid,
 		parent	 	=> $track->fader,
 		type		=> 'klg',	  		 # Ecasound controller
-		params => [	1,				 # Ecasound parameter 1
+		params => [	1,				 # modify first parameter of fader op 
 					 		$off_level,
 					 		$on_level,
 					 		@pairs,
@@ -111,7 +95,6 @@ sub refresh_fade_controller {
 	# 	first fade is type 'in'  : 0
 	# 	first fade is type 'out' : 100%
 	
-	 
 	update_effect($track->fader,0, initial_level($track->name) * 100)
 }
 
@@ -162,6 +145,8 @@ sub fades {
 
 sub initial_level {
 	# return 0, 1 or undef
+	# 0: track starts silent
+	# 1: track starts at full volume
 	my $track_name = shift;
 	my @fades = fades($track_name) or return undef;
 	# if we fade in we'll hold level zero from beginning
@@ -235,7 +220,7 @@ sub fader_envelope_pairs {
 
 
 	# prepend number of pairs;
-	unshift @pairs, (scalar @pairs / 2);
+	unshift @pairs, (scalar @pairs / 2) if @pairs;
 	@pairs;
 }
 		
@@ -313,6 +298,8 @@ sub remove {
 	else { refresh_fade_controller($track) }
 }
 sub add_fader {
+	# if it is missing
+
 	my $name = shift;
 	my $track = $tn{$name};
 
@@ -321,13 +308,13 @@ sub add_fader {
 	# create a fader if necessary, place before first effect
 	# if it exists
 	
-	if (! $id){	
+	if (! $id or ! Audio::Nama::fxn($id)){	
 		my $first_effect = $track->ops->[0];
 		$id = add_effect({
 				before 	=> $first_effect, 
 				track	=> $track,
 				type	=> $config->{fader_op}, 
-				params 	=> [0], # HARDCODED
+				params 	=> [0], # XX hardcoded for -ea chain operator
 		});
 		$track->set(fader => $id);
 	}
@@ -340,7 +327,7 @@ sub fade_uses_mark {
 	grep{ $_->mark1 eq $mark_name or $_->mark2 eq $mark_name } values %Audio::Nama::Fade::by_index;
 }
 	
-sub apply_fades { 
+sub setup_fades { 
 	# + data from Fade objects residing in %Audio::Nama::Fade::by_name
 	# + apply to tracks 
 	#     * that are part of current chain setup
