@@ -1,6 +1,6 @@
 # ---------- Git Support ----------
 package Audio::Nama;
-use Modern::Perl '2020';
+use Modern::Perl;
 sub git { 
 	return if is_test_script();
 	$config->{use_git} or warn("@_: git command, but git is not enabled.
@@ -18,7 +18,7 @@ sub initialize_project_repository {
 		"No repo created for project ", project_dir()), 
 		return if not $config->{use_git} or is_test_script();
 	if (not -d repo_git_dir()){
-		pager("Creating git repository in ". repo_git_dir()); 
+		pager("Creating git repository in ", repo_git_dir()); 
 		create_repo;
 		init_repo_obj();
 		create_file_stubs();
