@@ -1,7 +1,7 @@
 # -------------------- Help ----------------------
 
 package Audio::Nama;
-use Modern::Perl '2020';
+use Modern::Perl;
 
 {
 no warnings 'uninitialized';
@@ -12,7 +12,7 @@ sub helpline {
 			if $text->{commands}->{$cmd}->{short};	
 	$out .=  "Category: $text->{commands}->{$cmd}->{type}\n";
 	my $what = munge_help($text->{commands}->{$cmd}->{what});
-	$out .=  "Description: $what";
+	$out .=  "Description: $what\n";
 	$out .=  "Usage: $cmd "; 
 
 	if ( $text->{commands}->{$cmd}->{parameters} 
@@ -301,8 +301,8 @@ transport => <<TRANSPORT,
    forward, fw        -  Forward some number of seconds, i.e. fw 75
    setpos, sp         -  Set the playback head position, i.e. setpos 49.2
    getpos, gp         -  Get the current head position 
-   jump-to-start, beg   - set playback head to beginning of audio file(s)
-   jump-to-end, end     - set playback head to end
+   to-start, beg      - set playback head to start
+   to-end, end        - set playback head to end
 TRANSPORT
 track_fader => <<'TRACKFADER',
    Track volume/pan fader can be used to change settings for the current track.
