@@ -21,7 +21,7 @@ our (%tn, $jack, $config);
 #      + illegal track method call generate an exception
 
 package Audio::Nama::IO;
-use Modern::Perl '2020';
+use Modern::Perl;
 use Carp;
 use Data::Dumper::Concise;
 our $VERSION = 1.0;
@@ -356,40 +356,35 @@ sub rectified { # client name from number
 
 {
 package Audio::Nama::IO::from_null;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub _device_id { 'null' }  
 }
 
 {
 package Audio::Nama::IO::to_null;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub _device_id { 'null' }
 }
 
 {
 package Audio::Nama::IO::from_rtnull;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub _device_id { 'rtnull' }  
 }
 
 {
 package Audio::Nama::IO::to_rtnull;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub _device_id { 'rtnull' }  
 }
 
 {
 package Audio::Nama::IO::from_wav;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub device_id { 
 	my $self = shift;
@@ -407,8 +402,7 @@ sub ports { 'system:capture_1' }
 }
 {
 package Audio::Nama::IO::to_wav;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub device_id { $_[0]->full_path }
 sub _format_template { $config->{raw_to_disk_format} } 
@@ -416,8 +410,7 @@ sub _format_template { $config->{raw_to_disk_format} }
 
 {
 package Audio::Nama::IO::from_loop;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub new {
 	my $class = shift;
@@ -433,15 +426,13 @@ sub _format_template { $config->{cache_to_disk_format} }
 }
 {
 package Audio::Nama::IO::to_loop;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO::from_loop';
 }
 
 {
 package Audio::Nama::IO::from_soundcard;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub new {
 	shift; # throw away class
@@ -451,8 +442,7 @@ sub new {
 }
 {
 package Audio::Nama::IO::to_soundcard;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub new {
 	shift; # throw away class
@@ -462,8 +452,7 @@ sub new {
 }
 {
 package Audio::Nama::IO::to_jack_multi;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub client { 
 	my $self = shift;
@@ -479,16 +468,14 @@ sub device_id {
 
 {
 package Audio::Nama::IO::from_jack_multi;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO::to_jack_multi';
 sub ecs_extra { $_[0]->mono_to_stereo }
 }
 
 {
 package Audio::Nama::IO::to_jack_port;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub format_template { $config->{devices}->{jack}->{signal_format} }
 sub device_id { 'jack,,'.$_[0]->port_name.'_out' }
@@ -497,8 +484,7 @@ sub ports { $config->{ecasound_jack_client_name}. ":".$_[0]->port_name. '_out_1'
 
 {
 package Audio::Nama::IO::from_jack_port;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO::to_jack_port';
 sub device_id { 'jack,,'.$_[0]->port_name.'_in' }
 sub ecs_extra { $_[0]->mono_to_stereo }
@@ -507,8 +493,7 @@ sub ports { $config->{ecasound_jack_client_name}.":".$_[0]->port_name. '_in_1' }
 
 {
 package Audio::Nama::IO::to_jack_client;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub device_id { "jack," . Audio::Nama::IO::quote_jack_port($_[0]->send_id); }
 sub client { Audio::Nama::IO::rectified($_[0]->send_id) }
@@ -516,8 +501,7 @@ sub client { Audio::Nama::IO::rectified($_[0]->send_id) }
 
 {
 package Audio::Nama::IO::from_jack_client;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub device_id { 'jack,'.  Audio::Nama::IO::quote_jack_port($_[0]->source_id); }
 sub ecs_extra { $_[0]->mono_to_stereo}
@@ -526,8 +510,7 @@ sub client { Audio::Nama::IO::rectified($_[0]->source_id) }
 
 {
 package Audio::Nama::IO::from_alsa_soundcard_device;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub ecs_extra { join ' ', $_[0]->rec_route, $_[0]->mono_to_stereo }
 sub device_id { $config->{devices}->{$config->{alsa_capture_device}}->{ecasound_id} }
@@ -548,8 +531,7 @@ sub rec_route {
 }
 {
 package Audio::Nama::IO::to_alsa_soundcard_device;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub device_id { $config->{devices}->{$config->{alsa_playback_device}}{ecasound_id} }
 sub ecs_extra {route($_[0]->width,$_[0]->output_channel) }
@@ -573,8 +555,7 @@ sub route {
 }
 {
 package Audio::Nama::IO::from_bus;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 sub new {
 	my $class = shift;
@@ -585,8 +566,7 @@ sub new {
 }
 {
 package Audio::Nama::IO::any;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 our @ISA = 'Audio::Nama::IO';
 }
 
