@@ -1,6 +1,6 @@
 # ------ Memoize subroutines ------
 package Audio::Nama;
-use Modern::Perl '2020';
+use Modern::Perl;
 use Memoize qw(memoize unmemoize);
 
 BEGIN { # OPTMIZATION
