@@ -1,7 +1,7 @@
 package Audio::Nama::StatusSnapshot;
 
 use Role::Tiny;
-use Modern::Perl '2020';
+use Modern::Perl;
 {
 package Audio::Nama;
 
