@@ -1,7 +1,6 @@
 package Audio::Nama::TrackIO;
 use Role::Tiny;
-use Modern::Perl '2020';
-our $VERSION = 1.0;
+use Modern::Perl;
 use Audio::Nama::Globals qw(:all);
 use File::Slurp qw(write_file);
 use File::Copy;
@@ -232,9 +231,9 @@ sub output_object_text {   # text for user display
 sub source_status {
 	my $track = shift;
 	no warnings 'uninitialized';
-	return $track->current_wav if $track->rw eq PLAY and scalar $track->versions->@*; # files to play
+	return $track->current_wav if $track->play;
 	my $bus = $bn{$track->source_id}; 
-	return join " ", $bus->name, $bus->display_type if $track->source_type eq 'bus' and defined $bus; 
+	return join " ", $bus->name, $bus->display_type if $track->source_type eq 'bus';
 	return "track ".$track->source_id  if $track->source_type eq 'track';
 	return 'jack client '.$track->source_id if $track->source_type eq 'jack_client';
 	if($track->source_type eq 'soundcard')
@@ -322,7 +321,7 @@ sub import_audio  {
 		return;
 	}
 	my ($depth,$width,$freq) = split ',', Audio::Nama::wav_format($path);
-	Audio::Nama::pager_newline("format: ". Audio::Nama::wav_format($path));
+	Audio::Nama::pager_newline("format: ", Audio::Nama::wav_format($path));
 	$frequency ||= $freq;
 	if ( ! $frequency ){
 		Audio::Nama::throw("Cannot detect sample rate of $path. Skipping.",
